==> tendenci-7.1.30.tar.gz: tendenci-7.1.30/README.md <==
# Tendenci

Tendenci is an open source content management system built for non-profits, associations and cause-based sites with functionality including association management, event registration, membership management, donations, payments, newsletters, CRM, and much more.

Tendenci 7+ is the latest version that is compatible with Django 1.8. Currently, it's only available on github - hasn't been pushed to pypi yet. 

## Important Update for Self Hosted Tendenci Sites (Posted 9.21.15)
We will be refactoring the Tendenci code starting October 1, 2015

This will make it easier for you to work with the Tendenci code as a developer!

We appreciate your participation in our community and have created documentation to allow you to manually update your site to the latest version of Tendenci https://tendenci.readthedocs.org/en/latest/upgrade/5.1.html

After October 1, 2015 automatic updates should not be run if you are self hosting on Tendenci 5. Please manually update instead.

You can read more about why we are making this change and further details on our blog: http://blog.tendenci.com/refactoring-tendenci-7-1/

If you are reading this after we have removed the deprecated repos you can still get a copy of the old code for the various add-ons that are now integrated into apps by going to [https://www.tendenci.com/download/release-archive/](https://www.tendenci.com/download/release-archive/) but please instead go to [https://tendenci.readthedocs.org](https://tendenci.readthedocs.org) and upgrade to the latest release.

## Demo?  

You can self install of course. Or you can do a free 30 day trial without risk at 
[https://create.tendenci.com/](https://create.tendenci.com)


## Installation

Please see install documents located at:

https://tendenci.readthedocs.org


## Vision 

"Connect and Organize the World's People" 


## Mission

Our mission: "To make Tendenci the number 1 platform for NPOs/NGOs/Arts organizations globally."  


## License

The License information (GNU GPL) can be found at [https://github.com/tendenci/tendenci/blob/master/LICENSE.md](https://github.com/tendenci/tendenci/blob/master/LICENSE.md)


## Credits

Props [https://github.com/tendenci/tendenci/blob/master/docs/credits.md](https://github.com/tendenci/tendenci/blob/master/docs/credits.md)

==> tendenci-7.2.38.tar.gz: tendenci-7.2.38/README.md <==
# Tendenci

Tendenci is an open source content management system built for non-profits, associations and cause-based sites with functionality including association management, event registration, membership management, donations, payments, newsletters, CRM, and much more.

Tendenci 7+ is the latest version that is compatible with Django 1.8. Currently, it's only available on github - hasn't been pushed to pypi yet. 

## Important Update for Self Hosted Tendenci Sites (Posted 9.21.15)
We will be refactoring the Tendenci code starting October 1, 2015

This will make it easier for you to work with the Tendenci code as a developer!

We appreciate your participation in our community and have created documentation to allow you to manually update your site to the latest version of Tendenci https://tendenci.readthedocs.org/en/latest/upgrade/5.1.html

After October 1, 2015 automatic updates should not be run if you are self hosting on Tendenci 5. Please manually update instead.

You can read more about why we are making this change and further details on our blog: http://blog.tendenci.com/refactoring-tendenci-7-1/

If you are reading this after we have removed the deprecated repos you can still get a copy of the old code for the various add-ons that are now integrated into apps by going to [https://www.tendenci.com/download/release-archive/](https://www.tendenci.com/download/release-archive/) but please instead go to [https://tendenci.readthedocs.org](https://tendenci.readthedocs.org) and upgrade to the latest release.

## Demo?  

You can self install of course, or to demo the Tendenci software visit https://demo.tendenci.com/

Ready to start building out your Tendenci Site? You can do a free 30 day trial without risk at [https://create.tendenci.com/](https://create.tendenci.com) (Credit card sign up is required for the 30 day trial.)


## Installation

Please see install documents located at:

https://tendenci.readthedocs.org


## Vision 

"Connect and Organize the World's People" 


## Mission

Our mission: "To make Tendenci the number 1 platform for NPOs/NGOs/Arts organizations globally."  


## License

The License information (GNU GPL) can be found at [https://github.com/tendenci/tendenci/blob/master/LICENSE.md](https://github.com/tendenci/tendenci/blob/master/LICENSE.md)


## Credits

Props [https://github.com/tendenci/tendenci/blob/master/docs/credits.md](https://github.com/tendenci/tendenci/blob/master/docs/credits.md)
